Package 'assorthead'

Title: Assorted Header-Only C++ Libraries
Description: Vendors an assortment of useful header-only C++ libraries. Bioconductor packages can use these libraries in their own C++ code by LinkingTo this package without introducing any additional dependencies. The use of a central repository avoids duplicate vendoring of libraries across multiple R packages, and enables better coordination of version updates across cohorts of interdependent C++ libraries.
Authors: Aaron Lun [cre, aut]
Maintainer: Aaron Lun <[email protected]>
License: MIT + file LICENSE
Version: 1.7.7
Built: 2026-05-25 11:51:50 UTC
Source: https://github.com/bioc/assorthead

Help Index


assorthead: Assorted Header-Only C++ Libraries

Description

Vendors an assortment of useful header-only C++ libraries. Bioconductor packages can use these libraries in their own C++ code by LinkingTo this package without introducing any additional dependencies. The use of a central repository avoids duplicate vendoring of libraries across multiple R packages, and enables better coordination of version updates across cohorts of interdependent C++ libraries.

Author(s)

Maintainer: Aaron Lun [email protected]

See Also

Useful links: